@@ -12,11 +12,11 @@ C<Math::Geometry::Construction::Derivate::IntersectionCircleLine> - circle line
 
 =head1 VERSION
 
-Version 0.018
+Version 0.020
 
 =cut
 
-our $VERSION = '0.018';
+our $VERSION = '0.020';
 
 
 ###########################################################################
@@ -25,6 +25,21 @@ our $VERSION = '0.018';
 #                                                                         #
 ###########################################################################
 
+sub BUILD {
+    my ($self, $args) = @_;
+
+    my @input = $self->input;
+    croak "Need one circle and one line to intersect" if(@input != 2);
+    unless(eval { $input[0]->isa('Math::Geometry::Construction::Circle') }
+	   and
+	   eval { $input[1]->isa('Math::Geometry::Construction::Line') }
+	   or
+	   eval { $input[0]->isa('Math::Geometry::Construction::Line') }
+	   and
+	   eval { $input[1]->isa('Math::Geometry::Construction::Circle') })
+    { croak "Need one circle and one line to intersect" }
+}
+
 ###########################################################################
 #                                                                         #
 #                             Retrieve Data                               #
@@ -35,23 +50,9 @@ sub calculate_positions {
     my ($self) = @_;
     my @input  = $self->input;
 
-    croak "Need one circle and one line to intersect" if(@input != 2);
-
-    my $circle;
-    my $line;
-    if(eval { $input[0]->isa('Math::Geometry::Construction::Circle') }
-       and
-       eval { $input[1]->isa('Math::Geometry::Construction::Line') })
-    {
-	($circle, $line) = @input;
-    }
-    elsif(eval { $input[0]->isa('Math::Geometry::Construction::Line') }
-	  and
-	  eval { $input[1]->isa('Math::Geometry::Construction::Circle') })
-    {
-	($line, $circle) = @input;
-    }
-    else { croak "Need one circle and one line to intersect"  }
+    my $circle_class = 'Math::Geometry::Construction::Circle';
+    my ($circle, $line) = $input[0]->isa($circle_class)
+        ? @input : reverse(@input);
        
     my $c_center_p  = $circle->center->position;
     my $c_radius    = $circle->radius;
@@ -61,12 +62,8 @@ sub calculate_positions {
 	return if(!defined($_));
     }
 
-    my $l_distance = $l_support_p[1] - $l_support_p[0];
-    my $d          = abs($l_distance);
-    return if($d == 0);
-
-    my $l_parallel = $l_distance / $d;
-    my $l_normal   = $l_parallel->normal_base;
+    my $l_parallel = $line->parallel or return;
+    my $l_normal   = $line->normal;
     my $l_constant = $l_normal * $l_support_p[0];
 
     my $a   = $l_normal * $c_center_p - $l_constant;
@@ -74,8 +71,8 @@ sub calculate_positions {
     return if($rad < 0);
     my $b   = sqrt($rad);
     
-    return($c_center_p - $l_normal * $a + $l_parallel * $b,
-	   $c_center_p - $l_normal * $a - $l_parallel * $b);
+    return($c_center_p - $l_normal * $a - $l_parallel * $b,
+	   $c_center_p - $l_normal * $a + $l_parallel * $b);
 }
 
 ###########################################################################
